@@ -181,6 +181,19 @@ authselect_feature_enable(const char *feature);
 int
 authselect_feature_disable(const char *feature);
 
+/**
+ * Check if a feature is enabled in currently activated profile.
+ *
+ * @param feature       Feature name to check.
+ *
+ * @return
+ * - 0 if the feature is enabled.
+ * - ENOENT if it is disabled or there is no existing authselect configuration.
+ * - Other errno code on generic error.
+ */
+int
+authselect_feature_enabled(const char *feature);
+
 /**
  * Check if current configuration is valid.
  *
