@@ -11,13 +11,13 @@ fi
 . /etc/os-release
 
 case "$ID" in
-  fedora)
+  fedora | centos | rhel)
     [ ! -f "rpm/authselect.spec.in" ] && die "Missing file: rpm/authselect.spec.in"
     [ -f "authselect.spec" ] && die "./authselect.spec already exist, delete it to continue."
 
     sed -E "s/@\w+@/dummy/g" rpm/authselect.spec.in > authselect.spec
     dnf install -y "dnf-command(builddep)"
-    dnf builddep -y --spec ./authselect.spec
+    dnf builddep -y ./authselect.spec
     rm authselect.spec
     ;;
   ubuntu)
